import { AbstractFileSystem } from "./AbstractFileSystem";
import { CopyOptions, DeleteOptions, Directory, Entry, HeadOptions, MoveOptions, PatchOptions, Stats, URLOptions } from "./core";
import { ErrorLike, FileSystemError } from "./errors";
export declare abstract class AbstractEntry implements Entry {
    readonly fs: AbstractFileSystem;
    readonly path: string;
    stats: Stats | undefined | null;
    constructor(fs: AbstractFileSystem, path: string);
    copy(to: Entry, options?: CopyOptions, errors?: FileSystemError[]): Promise<boolean>;
    cp: (to: Entry, options?: CopyOptions, errors?: FileSystemError[]) => Promise<boolean>;
    del: (options?: DeleteOptions, errors?: FileSystemError[]) => Promise<boolean>;
    delete(options?: DeleteOptions, errors?: FileSystemError[]): Promise<boolean>;
    getParent(): Directory;
    move(to: Entry, options?: MoveOptions, errors?: FileSystemError[]): Promise<boolean>;
    mv: (to: Entry, options?: MoveOptions, errors?: FileSystemError[]) => Promise<boolean>;
    patch: (props: Stats, options?: PatchOptions, errors?: FileSystemError[]) => Promise<boolean>;
    remove: (options?: DeleteOptions, errors?: FileSystemError[]) => Promise<boolean>;
    rm: (options?: DeleteOptions, errors?: FileSystemError[]) => Promise<boolean>;
    stat(options?: HeadOptions): Promise<Stats>;
    toString: () => string;
    toURL(options?: URLOptions): Promise<string>;
    abstract _copy(entry: Entry, options: CopyOptions, errors?: FileSystemError[]): Promise<boolean>;
    abstract _deleteExisting(option: DeleteOptions, errors?: FileSystemError[]): Promise<boolean>;
    abstract _validate(options?: HeadOptions): Promise<void>;
    abstract head(options?: HeadOptions): Promise<Stats>;
    abstract head(options?: HeadOptions, errors?: FileSystemError[]): Promise<Stats | null>;
    protected __delete(options: DeleteOptions, errors?: FileSystemError[]): Promise<boolean>;
    protected _afterDelete(result: boolean, options: DeleteOptions, error?: FileSystemError): Promise<void>;
    protected _beforeDelete(options: DeleteOptions): Promise<boolean | null>;
    protected _createError(error: ErrorLike): FileSystemError;
    protected _createNoModificationAllowedError(additional?: Partial<ErrorLike>): FileSystemError;
    protected _createNotFoundError(additional?: Partial<ErrorLike>): FileSystemError;
    protected _createNotReadableError(additional?: Partial<ErrorLike>): FileSystemError;
    protected _createTypeMismatchError(additional?: Partial<ErrorLike>): FileSystemError;
    protected _handleNoModificationAllowedError(cause: Partial<ErrorLike>, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
    protected _handleNotFoundError(cause: Partial<ErrorLike>, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
    protected _handleNotReadableError(cause: Partial<ErrorLike>, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
    protected _handleTypeMismatchError(cause: Partial<ErrorLike>, errors?: FileSystemError[], callback?: (e: FileSystemError) => Promise<void>): Promise<void>;
}
//# sourceMappingURL=AbstractEntry.d.ts.map