/// <reference types="node" />
import { Data, DataType, ReturnData } from "univ-conv";
import { AbstractEntry } from "./AbstractEntry";
import { AbstractFileSystem } from "./AbstractFileSystem";
import { CopyOptions, Entry, File, HeadOptions, ReadOptions, Stats, WriteOptions } from "./core";
import { FileSystemError } from "./errors";
export declare abstract class AbstractFile extends AbstractEntry implements File {
    constructor(fs: AbstractFileSystem, path: string);
    _copy(toFile: Entry, options: CopyOptions, errors?: FileSystemError[]): Promise<boolean>;
    _deleteExisting(): Promise<boolean>;
    _validate(options?: HeadOptions): Promise<void>;
    _write(data: Data, options?: WriteOptions, errors?: FileSystemError[]): Promise<boolean>;
    hash(options?: ReadOptions): Promise<string>;
    hash(options?: ReadOptions, errors?: FileSystemError[]): Promise<string | null>;
    head(options?: HeadOptions): Promise<Stats>;
    head(options?: HeadOptions, errors?: FileSystemError[]): Promise<Stats | null>;
    read<T extends DataType>(type?: T, options?: ReadOptions): Promise<ReturnData<T>>;
    read<T extends DataType>(type?: T, options?: ReadOptions, errors?: FileSystemError[]): Promise<ReturnData<T> | null>;
    write(data: Data, options?: WriteOptions, errors?: FileSystemError[]): Promise<boolean>;
    abstract _doDelete(): Promise<void>;
    abstract _doRead(stats: Stats, options: ReadOptions): Promise<Data>;
    abstract _doWrite(data: Data, stats: Stats | undefined | null, options: WriteOptions): Promise<void>;
    abstract supportAppend(): boolean;
    abstract supportRangeRead(): boolean;
    abstract supportRangeWrite(): boolean;
    protected $write(data: Data, options: WriteOptions): Promise<boolean>;
    protected __read(options: ReadOptions): Promise<Data>;
    protected _afterGet(options: ReadOptions, data: Data | null, error?: FileSystemError): Promise<void>;
    protected _afterPost(options: WriteOptions, result: boolean, error?: FileSystemError): Promise<void>;
    protected _afterPut(options: WriteOptions, result: boolean, error?: FileSystemError): Promise<void>;
    protected _beforeGet(options: ReadOptions): Promise<string | ArrayBuffer | import("stream").Readable | Blob | ReadableStream<Uint8Array> | null>;
    protected _beforePost(data: Data, options: WriteOptions): Promise<void>;
    protected _beforePut(data: Data, options: WriteOptions): Promise<void>;
    protected _getConverter(): import("univ-conv").DefaultConverter;
    protected _read(options: ReadOptions): Promise<Data>;
    protected _read(options: ReadOptions, errors?: FileSystemError[]): Promise<Data | null>;
}
//# sourceMappingURL=AbstractFile.d.ts.map