import { Data, DataType, ReturnData } from "univ-conv";
import { CopyOptions, DeleteOptions, Directory, Entry, File, FileSystem, FileSystemOptions, HeadOptions, ListOptions, MkcolOptions, MoveOptions, PatchOptions, ReadOptions, Stats, URLOptions, WriteOptions } from "./core";
import { ErrorParams, FileSystemError } from "./errors";
export declare abstract class AbstractFileSystem implements FileSystem {
    readonly repository: string;
    readonly options: FileSystemOptions;
    readonly defaultCopyOptions: CopyOptions;
    readonly defaultDeleteOptions: DeleteOptions;
    readonly defaultHeadOptions: HeadOptions;
    readonly defaultMkcolOptions: MkcolOptions;
    readonly defaultMoveOptions: MoveOptions;
    readonly defaultPatchOptions: PatchOptions;
    readonly defaultReadOptions: ReadOptions;
    readonly defaultWriteOptions: WriteOptions;
    constructor(repository: string, options?: FileSystemOptions);
    _createError(params: ErrorParams): FileSystemError;
    _handleError(params: ErrorParams, errors?: FileSystemError[], callback?: (error: FileSystemError) => Promise<void>): Promise<void>;
    _handleFileSystemError(error: FileSystemError, errors?: FileSystemError[], callback?: (error: FileSystemError) => Promise<void>): Promise<void>;
    copy(fromPath: string, toPath: string, options?: CopyOptions, errors?: FileSystemError[]): Promise<boolean>;
    cp: (fromPath: string, toPath: string, options?: CopyOptions, errors?: FileSystemError[]) => Promise<boolean>;
    del: (path: string, options?: DeleteOptions, errors?: FileSystemError[]) => Promise<boolean>;
    delete(path: string, options?: DeleteOptions, errors?: FileSystemError[]): Promise<boolean>;
    dir(path: string, options?: ListOptions): Promise<string[]>;
    dir(path: string, options?: ListOptions, errors?: FileSystemError[]): Promise<string[] | null>;
    getDirectory(path: string): Directory;
    getEntry(path: string, options?: HeadOptions): Promise<Entry>;
    getEntry(path: string, options?: HeadOptions, errors?: FileSystemError[]): Promise<Entry | null>;
    getFile(path: string): File;
    getURL(path: string, options?: URLOptions): Promise<string>;
    getURL(path: string, options?: URLOptions, errors?: FileSystemError[]): Promise<string | null>;
    hash(path: string, options?: ReadOptions): Promise<string>;
    hash(path: string, options?: ReadOptions, errors?: FileSystemError[]): Promise<string | null>;
    head(path: string, options?: HeadOptions): Promise<Stats>;
    head(path: string, options?: HeadOptions, errors?: FileSystemError[]): Promise<Stats | null>;
    list(path: string, options?: ListOptions): Promise<string[]>;
    list(path: string, options?: ListOptions, errors?: FileSystemError[]): Promise<string[] | null>;
    ls(path: string, options?: ListOptions): Promise<string[]>;
    mkcol(path: string, options?: MkcolOptions, errors?: FileSystemError[]): Promise<boolean>;
    mkdir: (path: string, options?: MkcolOptions, errors?: FileSystemError[]) => Promise<boolean>;
    move(fromPath: string, toPath: string, options?: MoveOptions, errors?: FileSystemError[]): Promise<boolean>;
    mv: (fromPath: string, toPath: string, options?: MoveOptions, errors?: FileSystemError[]) => Promise<boolean>;
    patch(path: string, props: Stats, options?: PatchOptions, errors?: FileSystemError[]): Promise<boolean>;
    read<T extends DataType>(path: string, type?: T, options?: ReadOptions): Promise<ReturnData<T>>;
    readdir(path: string, options?: ListOptions, errors?: FileSystemError[]): Promise<string[]>;
    rm: (path: string, options?: DeleteOptions, errors?: FileSystemError[]) => Promise<boolean>;
    stat(path: string, options?: HeadOptions): Promise<Stats>;
    stat(path: string, options?: HeadOptions, errors?: FileSystemError[]): Promise<Stats | null>;
    unlink: (path: string, options?: DeleteOptions) => Promise<boolean>;
    write(path: string, data: Data, options?: WriteOptions, errors?: FileSystemError[]): Promise<boolean>;
    abstract _doGetDirectory(path: string): Directory;
    abstract _doGetFile(path: string): File;
    abstract _doGetURL(path: string, isDirectory: boolean, options: URLOptions): Promise<string>;
    abstract _doHead(path: string, options: HeadOptions): Promise<Stats>;
    abstract _doPatch(path: string, stats: Stats, props: Stats, options: PatchOptions): Promise<void>;
    abstract canPatchAccessed(): boolean;
    abstract canPatchCreated(): boolean;
    abstract canPatchModified(): boolean;
    abstract supportDirectory(): boolean;
    protected __head(path: string, options: HeadOptions): Promise<Stats | null>;
    protected _afterHead(path: string, stats: Stats | null, options: HeadOptions, error?: FileSystemError): Promise<void>;
    protected _afterPatch(path: string, result: boolean, options: PatchOptions, error?: FileSystemError): Promise<void>;
    protected _beforeHead(path: string, options: HeadOptions): Promise<Stats | null>;
    protected _beforePatch(path: string, props: Stats, options: PatchOptions): Promise<boolean | null>;
    protected _checkPath(path: string): string;
    protected _fixProps(path: string, props: Stats, stats: Stats): void;
    private _prepareCopy;
}
//# sourceMappingURL=AbstractFileSystem.d.ts.map