"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
const univ_conv_1 = require("univ-conv");
class ModifiedReadable extends stream_1.Readable {
    src;
    iStart = 0;
    mods;
    constructor(src, ...mods) {
        super();
        this.src = src;
        this.mods = mods;
        src.once("readable", () => this.setup());
    }
    setup() {
        const onData = (value) => {
            const chunk = value;
            const size = chunk.byteLength;
            try {
                const iEnd = this.iStart + size;
                for (const mod of this.mods) {
                    const mStart = mod.start ?? 0;
                    const mEnd = mStart + (mod.length ?? Number.MAX_SAFE_INTEGER);
                    if (mStart <= this.iStart && iEnd <= mEnd) {
                        const start = this.iStart - mStart;
                        const length = size;
                        this.push(univ_conv_1.DEFAULT_CONVERTER.slice(mod.data, { start, length }));
                        return;
                    }
                    else if (this.iStart <= mStart && mStart <= iEnd) {
                        const chunkLen = mStart - this.iStart;
                        if (0 < chunkLen) {
                            this.push(chunk.slice(0, chunkLen));
                        }
                        if (mEnd < iEnd) {
                            const modLen = mEnd - mStart;
                            this.push(univ_conv_1.DEFAULT_CONVERTER.slice(mod.data, {
                                start: 0,
                                length: modLen,
                            }));
                            if (mEnd < iEnd) {
                                const start = mEnd - this.iStart;
                                const length = iEnd - mEnd;
                                this.push(chunk.slice(start, length));
                            }
                        }
                        return;
                    }
                    else if (mStart < this.iStart && this.iStart < mEnd) {
                        const start = this.iStart - mStart;
                        let length;
                        if (mEnd < iEnd) {
                            length = mEnd - this.iStart;
                        }
                        else {
                            length = iEnd - this.iStart;
                        }
                        this.push(univ_conv_1.DEFAULT_CONVERTER.slice(mod.data, { start, length }));
                        return;
                    }
                    this.push(chunk);
                }
            }
            finally {
                this.iStart += size;
            }
        };
        const src = this.src;
        src.once("error", (e) => {
            this.destroy(e);
            src.off("data", onData);
        });
        src.once("end", () => {
            this.push(null);
            src.off("data", onData);
        });
        src.on("data", onData);
    }
    _read() {
    }
}
exports.default = ModifiedReadable;
//# sourceMappingURL=mods-node.js.map