"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toHex = exports.createMetadata = exports.isIllegalFileName = exports.normalizePath = exports.joinPaths = exports.getName = exports.getParentPath = exports.getPathParts = exports.INVALID_CHARS = void 0;
const core_1 = require("./core");
const errors_1 = require("./errors");
exports.INVALID_CHARS = /[\x00-\x1F\x7F-\x9F\\:*"<>|]/;
function getPathParts(path) {
    const parts = path.split("/");
    const pathParts = [];
    for (const part of parts) {
        if (part === "..") {
            if (pathParts.length === 0) {
                throw (0, errors_1.createError)({
                    message: "Illegal path",
                    name: errors_1.SyntaxError.name,
                    path,
                });
            }
            pathParts.pop();
        }
        else if (part === ".") {
        }
        else if (part !== "") {
            pathParts.push(part);
        }
    }
    return pathParts;
}
exports.getPathParts = getPathParts;
function getParentPath(path) {
    let parts = getPathParts(path);
    if (parts.length <= 1) {
        return "/";
    }
    parts = parts.slice(0, -1);
    return "/" + parts.join("/");
}
exports.getParentPath = getParentPath;
function getName(path) {
    const parts = getPathParts(path);
    if (parts.length === 0) {
        return "";
    }
    return parts[parts.length - 1];
}
exports.getName = getName;
function joinPaths(path1, path2, leadingSlash = true) {
    const parts1 = getPathParts(path1);
    const parts2 = getPathParts(path2);
    const parts = [...parts1, ...parts2];
    return (leadingSlash ? "/" : "") + parts.join("/");
}
exports.joinPaths = joinPaths;
function normalizePath(path, leadingSlash = true) {
    const parts = getPathParts(path);
    return (leadingSlash ? "/" : "") + parts.join("/");
}
exports.normalizePath = normalizePath;
function isIllegalFileName(name) {
    return /[\x00-\x1f\x7f-\x9f\\/:*?"<>|]/.test(name);
}
exports.isIllegalFileName = isIllegalFileName;
function createMetadata(props) {
    const metadata = {};
    for (const [key, value] of Object.entries(props)) {
        if (0 <= core_1.DEFAULT_STATS_KEYS.indexOf(key))
            continue;
        if (value == null)
            continue;
        metadata[key] = value.toString();
    }
    return metadata;
}
exports.createMetadata = createMetadata;
const LUT_HEX_4b = new Array(0x10);
for (let n = 0; n < 0x10; n++) {
    LUT_HEX_4b[n] = n.toString(16);
}
const LUT_HEX_8b = new Array(0x100);
for (let n = 0; n < 0x100; n++) {
    LUT_HEX_8b[n] = `${LUT_HEX_4b[(n >>> 4) & 0xf]}${LUT_HEX_4b[n & 0xf]}`;
}
function toHex(u8) {
    return u8.reduce((result, i) => result + LUT_HEX_8b[i], "");
}
exports.toHex = toHex;
//# sourceMappingURL=util.js.map